#include <math.h>
#include <gdk/gdkkeysyms.h>
#include <gtk/gtk.h>
#include "gamerender.h"
#ifdef SOUND_LINUX
#include "sound.h"
#endif

float ball_x = 0.0;
float ball_y = 0.0;
float b_dx;
float b_dy;

float ball_vel_x = 120.0;
float ball_vel_y = 0.0;

int ball_moving = 0;

int one_dir = 0;
int two_dir = 0;

float one_pos = 0.0;
float two_pos = 0.0;

int one_points = 0;
int two_points = 0;

float one_vel = 70.0;
float two_vel = 70.0;

double game_time;
double game_tick;

float angle_rate = 3.5;
int max_points = 5;

char player_names[2][20]={"Player 1","Player 2"};

int player_won = 0;

#ifdef SOUND_LINUX
extern char coll_snd[1025];
extern int coll_sndc;
#endif

void game_init()
{
  game_time = gdk_time_get() / 1000.0;
  game_tick  = 1.0 / 60;
}

void game_restart()
{
  game_init();
  ball_x = 0.0;
  ball_y = 0.0;
  one_pos = 0.0;
  two_pos = 0.0;
  ball_moving = 0;
  ball_vel_y = 0.0;
}

void game_finish()
{
  game_restart();
  one_points = 0;
  two_points = 0;
}


void game_play()
{
  double time_now,tick_now;
  float p_dy;

  
  /* timing */
  time_now = gdk_time_get() / 1000.0;
  tick_now = time_now - game_time;
  if (tick_now < 0.001) tick_now = 0.001;
  if (tick_now > 0.2  ) tick_now = 0.2;
  game_tick = (tick_now + 4*game_tick)/5; /* average */
  game_time = time_now;
  /* move the paddles */
    
  
  if(ball_moving){
    player_won = 0;
    /* check collisions */
    if(ball_x < -140.0 &&  (ball_y  < (one_pos + 20.0) && ball_y > (one_pos - 20.0) && ball_moving) && ball_vel_x < 0){
      ball_vel_x = -ball_vel_x;
      p_dy = ball_y - one_pos;
      ball_vel_y += p_dy * angle_rate;
      //g_print("%f %f\n",p_dy,ball_vel_y);
      //g_print("Played sound\n");
#ifdef SOUND_LINUX
      play_sound(coll_snd,coll_sndc);
#endif
    }
    if(ball_x < -155){
      two_points++;
      if(two_points == max_points){
	player_won = 2;
	game_finish();
      }
      else game_restart();
    }
    if(ball_x > 140.0 &&  (ball_y  < (two_pos + 20.0) && ball_y > (two_pos - 20.0) && ball_moving) && ball_vel_x > 0){
      ball_vel_x = -ball_vel_x;
      p_dy = ball_y - two_pos;
      ball_vel_y += p_dy* angle_rate;
      //g_print("%f %f\n",p_dy,ball_vel_y);
#ifdef SOUND_LINUX
      play_sound(coll_snd,coll_sndc);
#endif SOUND_LINUX
    }
    if(ball_x > 155){
      one_points++;
      if(one_points == max_points){
	player_won = 1;
	game_finish();
      }
      else game_restart();
    }
    /*move ball*/
    b_dx = ball_vel_x * game_tick;
    b_dy = ball_vel_y * game_tick;
    ball_x += b_dx;
    ball_y += b_dy;
    
    /*move paddles*/
    if(one_pos < 106 && one_pos > -106)
      one_pos += one_vel * one_dir * game_tick;
    else if(one_pos > 106 && one_dir == -1)
      one_pos += one_vel * one_dir * game_tick;
    else if(one_pos < -106 && one_dir == 1)
      one_pos += one_vel * one_dir * game_tick;
    if(two_pos < 106 && two_pos > -106)
      two_pos += two_vel * two_dir * game_tick;
    if(two_pos > 106 && two_dir == -1)
      two_pos += two_vel * two_dir * game_tick;
    else if( two_pos < -106 && two_dir == 1)
      two_pos += two_vel * two_dir * game_tick;
  
    if(ball_y > 84.0 || ball_y < -84.0) 
      ball_vel_y = -ball_vel_y;
    
  }
  //g_print("%f %f %f %f\n",ball_x,ball_y,two_pos,b_dx);
  
  
}

gint key_press_event(GtkWidget *widget, GdkEventKey *event)
{
  switch (event->keyval) {
  case GDK_s:
    one_dir = 1;
    break;
  case GDK_a:
  case GDK_x:
    one_dir = -1;
    break;
  case GDK_Left:
  case GDK_Up:
    two_dir = 1;
    break;
  case GDK_Right:
  case GDK_Down:
    two_dir = -1;
    break;
  case GDK_q:
    gtk_main_quit();
    break;
  case GDK_space:
    if(ball_moving == 0) ball_moving = 1;
    break;

  }
  /* prevent the default handler from being run */
  gtk_signal_emit_stop_by_name(GTK_OBJECT(widget),"key_press_event");
  return TRUE;
}

gint key_release_event(GtkWidget *widget, GdkEventKey *event)
{
  switch (event->keyval) {
  case GDK_s:
    if (one_dir == 1) one_dir = 0;
    break;
  case GDK_x:
    if (one_dir == -1) one_dir = 0;
    break;
  case GDK_Up:
    if(two_dir == 1) two_dir = 0;
  case GDK_Down:
    if(two_dir == -1) two_dir = 0;
    break;
  }
  /* prevent the default handler from being run */
  gtk_signal_emit_stop_by_name(GTK_OBJECT(widget),"key_release_event");
  return TRUE;
}
