#include <gtk/gtk.h>
#include <gdk/gdk.h>
#include "interface.h"
#include "callback.h"
#include "gameplay.h"
#include "gamerender.h"

extern float max_points;
extern char player_names[2][20];
extern float angle_rate;
extern float x_rot;
extern float y_rot;
extern float z_rot;

void show_settings()
{
  GtkWidget *settings_window = NULL, *close_button;
  /*boxes*/
  GtkWidget *settings_box,*hbox_1,*hbox_2,*hbox_3,*hbox_4,
    *hbox_5, *hbox_6, *hbox_7;
  /*labels*/
  GtkWidget *player1, *player2, *num_games, *angle_rate_label;
  /*entries*/
  GtkWidget *player1_entry,*player2_entry;
  /*spinners*/
  GtkWidget *num_games_spin, *angle_rate_spin;
  /*spinner's adjustment*/
  GtkAdjustment *adj_games, *adj_angle;
  
 
  //float angle_rate;
  //fprintf(stdout,"%f %d\n",angle_rate,max_points);
  
  settings_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
  gtk_signal_connect(GTK_OBJECT(settings_window),"destroy",
		     GTK_SIGNAL_FUNC(delete_settings_window),
		     &settings_window);
  gtk_window_set_title(GTK_WINDOW(settings_window),"Settings");
  settings_box = gtk_vbox_new(FALSE,0);
  gtk_container_add(GTK_CONTAINER(settings_window),settings_box);
  hbox_1 = gtk_hbox_new(FALSE,0);
  player1 = gtk_label_new("Player 1 name: ");
  gtk_box_pack_start(GTK_BOX(hbox_1),player1,FALSE,FALSE,0);
  player1_entry = gtk_entry_new_with_max_length(8);
  gtk_entry_set_text(GTK_ENTRY(player1_entry),player_names[0]);
  gtk_signal_connect(GTK_OBJECT(player1_entry),"activate",
		     GTK_SIGNAL_FUNC(change_name_player1),
		     player1_entry);
  gtk_box_pack_start(GTK_BOX(hbox_1),player1_entry,FALSE,FALSE,0);
  hbox_2 = gtk_hbox_new(FALSE,0);
  player2 = gtk_label_new("Player 2 name: ");
  gtk_box_pack_start(GTK_BOX(hbox_2),player2,FALSE,FALSE,0);
  player2_entry = gtk_entry_new_with_max_length(8);
  gtk_signal_connect(GTK_OBJECT(player2_entry),"activate",
		     GTK_SIGNAL_FUNC(change_name_player2),
		     player2_entry);
  gtk_entry_set_text(GTK_ENTRY(player2_entry),player_names[1]);
  gtk_box_pack_start(GTK_BOX(hbox_2),player2_entry,FALSE,FALSE,0);
  hbox_3 = gtk_hbox_new(FALSE,0);
  num_games = gtk_label_new("Number of games:");
  gtk_box_pack_start(GTK_BOX(hbox_3),num_games,FALSE,FALSE,0);
  
  adj_games = (GtkAdjustment *) gtk_adjustment_new((float)max_points,3.0,10.0,1.0,5.0,0.0);

  num_games_spin = gtk_spin_button_new(adj_games,0,0);
  gtk_signal_connect(GTK_OBJECT(adj_games),"value_changed",
		     GTK_SIGNAL_FUNC(update_max_points),
		     (gpointer) num_games_spin);
  gtk_box_pack_start(GTK_BOX(hbox_3),num_games_spin,FALSE,FALSE,0);
  hbox_4 = gtk_hbox_new(FALSE,0);
  angle_rate_label = gtk_label_new("Change rate of angle:");
  gtk_box_pack_start(GTK_BOX(hbox_4),angle_rate_label,FALSE,FALSE,0);
  adj_angle = (GtkAdjustment *)gtk_adjustment_new(angle_rate,0.0,
						  8.0,0.1,0.5,0.0);
  angle_rate_spin = gtk_spin_button_new(adj_angle,0,0);
  gtk_spin_button_set_digits(GTK_SPIN_BUTTON(angle_rate_spin),2);
  gtk_signal_connect(GTK_OBJECT(adj_angle),"value_changed",
		     GTK_SIGNAL_FUNC(update_angle_rate),
		     (gpointer) angle_rate_spin);
  
  gtk_box_pack_start(GTK_BOX(hbox_4),angle_rate_spin,FALSE,FALSE,0);
  close_button = gtk_button_new_with_label("Close");
  gtk_signal_connect_object_after(GTK_OBJECT(close_button),
				  "clicked",
				  GTK_SIGNAL_FUNC(gtk_widget_destroy),
				  GTK_OBJECT(settings_window));
  gtk_box_pack_start(GTK_BOX(settings_box),hbox_1,FALSE,FALSE,0);
  gtk_box_pack_start(GTK_BOX(settings_box),hbox_2,FALSE,FALSE,0);
  gtk_box_pack_start(GTK_BOX(settings_box),hbox_3,FALSE,FALSE,0);
  gtk_box_pack_start(GTK_BOX(settings_box),hbox_4,FALSE,FALSE,0);
  gtk_box_pack_start(GTK_BOX(settings_box),close_button,TRUE,TRUE,0);
  
  GTK_WIDGET_SET_FLAGS (close_button, GTK_CAN_DEFAULT); 
  gtk_widget_grab_default (close_button); 
  
  gtk_widget_show_all(settings_window);
}

void show_rotation()
{
  GtkWidget *rot_window = NULL, *close_button;
  GtkWidget *rot_box, *hbox;
  GtkWidget *x_label,*y_label,*z_label,*dist_label;
  GtkAdjustment *x_adj,*y_adj,*z_adj,*dist_adj;
  GtkWidget *x_bar,*y_bar,*z_bar,*dist_bar;

  rot_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
  gtk_signal_connect(GTK_OBJECT(rot_window),"destroy",
		     GTK_SIGNAL_FUNC(delete_rot_window),
		     &rot_window);
  gtk_window_set_title(GTK_WINDOW(rot_window),"Rotation");
  gtk_widget_set_usize(GTK_WIDGET(rot_window),150,220);
  rot_box = gtk_vbox_new(FALSE,0);
  gtk_container_add(GTK_CONTAINER(rot_window),rot_box);
  x_label = gtk_label_new("X Rotation");
  gtk_box_pack_start(GTK_BOX(rot_box),x_label,FALSE,FALSE,0);
  x_adj = (GtkAdjustment *)gtk_adjustment_new(x_rot,-90.0,90.0,1.0,5.0,1.0);
  x_bar = gtk_hscale_new(GTK_ADJUSTMENT(x_adj));
  gtk_signal_connect(GTK_OBJECT(x_adj),"value_changed",
		     GTK_SIGNAL_FUNC(update_x_rot),
		     (gpointer)x_adj);
  gtk_box_pack_start(GTK_BOX(rot_box),x_bar,FALSE,FALSE,0);

  y_label = gtk_label_new("Y Rotation");
  gtk_box_pack_start(GTK_BOX(rot_box),y_label,FALSE,FALSE,0);
  y_adj = (GtkAdjustment *)gtk_adjustment_new(y_rot,-90.0,90.0,1.0,5.0,1.0);
  y_bar = gtk_hscale_new(GTK_ADJUSTMENT(y_adj));
  gtk_signal_connect(GTK_OBJECT(y_adj),"value_changed",
		     GTK_SIGNAL_FUNC(update_y_rot),
		     (gpointer)y_adj);
  gtk_box_pack_start(GTK_BOX(rot_box),y_bar,FALSE,FALSE,0);
  
  z_label = gtk_label_new("Z Rotation");
  gtk_box_pack_start(GTK_BOX(rot_box),z_label,FALSE,FALSE,0);
  z_adj = (GtkAdjustment *)gtk_adjustment_new(z_rot,-90.0,90.0,1.0,5.0,1.0);
  z_bar = gtk_hscale_new(GTK_ADJUSTMENT(z_adj));
  gtk_signal_connect(GTK_OBJECT(z_adj),"value_changed",
		     GTK_SIGNAL_FUNC(update_z_rot),
		     (gpointer)z_adj);
  gtk_box_pack_start(GTK_BOX(rot_box),z_bar,FALSE,FALSE,0);

  dist_label = gtk_label_new("Distance");
  gtk_box_pack_start(GTK_BOX(rot_box),dist_label,FALSE,FALSE,0);
  dist_adj = (GtkAdjustment *)gtk_adjustment_new(z_rot,-90.0,90.0,1.0,5.0,1.0);
  dist_bar = gtk_hscale_new(GTK_ADJUSTMENT(dist_adj));
  gtk_signal_connect(GTK_OBJECT(dist_adj),"value_changed",
		     GTK_SIGNAL_FUNC(update_dist),
		     (gpointer)dist_adj);
  gtk_box_pack_start(GTK_BOX(rot_box),dist_bar,FALSE,FALSE,0);
  
  close_button = gtk_button_new_with_label("Close");
  gtk_signal_connect_object_after(GTK_OBJECT(close_button),
				  "clicked",
				  GTK_SIGNAL_FUNC(gtk_widget_destroy),
				  GTK_OBJECT(rot_window));
  gtk_box_pack_start(GTK_BOX(rot_box),close_button,TRUE,TRUE,0);
  
  GTK_WIDGET_SET_FLAGS (close_button, GTK_CAN_DEFAULT); 
  gtk_widget_grab_default (close_button); 
  
  gtk_widget_show_all(rot_window);
  
}

void show_about_box()
{
  GtkWidget *about_window = NULL;
  GtkWidget *about_box;
  GtkWidget *label1,*label2,*label3;
  GtkWidget *close_about_button;
  if(!about_window)
    {
      about_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
      gtk_signal_connect (GTK_OBJECT (about_window), "destroy",
			  GTK_SIGNAL_FUNC(delete_about_window),
			  &about_window);
      gtk_window_set_title(GTK_WINDOW(about_window),"About FooPong");
      //gtk_widget_set_usize(about_window,200,180);
      /*gtk_signal_connect(GTK_OBJECT(about_window),"delete_event",
	GTK_SIGNAL_FUNC(delete_about_window),about_window);*/
  
      about_box = gtk_vbox_new(FALSE,0);
      gtk_container_add(GTK_CONTAINER(about_window),about_box);
  
      label1 = gtk_label_new("FooPoNG !!!");
      gtk_box_pack_start(GTK_BOX(about_box),label1,FALSE,FALSE,15);
      label2 = gtk_label_new("     Mrbook & Mrbeavster   ");
      gtk_box_pack_start(GTK_BOX(about_box),label2,FALSE,FALSE,15);
      label3 = gtk_label_new("February 2000");
      gtk_box_pack_start(GTK_BOX(about_box),label3,FALSE,FALSE,15);
 
      close_about_button = gtk_button_new_with_label("Close");
      gtk_signal_connect_object_after(GTK_OBJECT(close_about_button),
				      "clicked",
				      GTK_SIGNAL_FUNC(gtk_widget_destroy),
				      GTK_OBJECT(about_window));
      gtk_box_pack_start(GTK_BOX(about_box),close_about_button,FALSE,FALSE,0);
      
    }
  if(!GTK_WIDGET_VISIBLE(about_window))
    {
      gtk_widget_show_all(about_window);
    }
  else {
    gtk_widget_destroy(about_window);
  }
}
