#include <gtk/gtk.h>
#include <gtkgl/gtkglarea.h>
#include <gdk/gdk.h>
#include "interface.h"
#include "gameplay.h"
#include "gamerender.h"
#include "callback.h"
#ifdef SOUND_LINUX
#include "sound.h"
#endif

static GtkItemFactoryEntry menu_items[] = {
  { "/_Game",         NULL,         NULL, 0, "<Branch>" },
  { "/Game/_New",     "<control>N",game_finish, 0, NULL },
  { "/Game/sep1",     NULL,         NULL, 0, "<Separator>" },
  { "/Game/Quit",     "<control>Q", gtk_main_quit, 0, NULL },
  { "/_Options",      NULL,         NULL, 0, "<Branch>" },
  { "/Options/Settings",  NULL,         show_settings, 0, NULL },
  { "/Options/Rotation",  NULL,         show_rotation, 0, NULL },
  { "/_Help",         NULL,         NULL, 0, "<LastBranch>" },
  { "/_Help/About",   NULL,         show_about_box, 0, NULL },
};

int main(int argc, char **argv)
{
  GtkWidget *window,*vbox,*logo,*menubar,*glarea;
  GtkItemFactory *item_factory;
  GtkAccelGroup *accel_group;
  gint nmenu_items = sizeof (menu_items) / sizeof (menu_items[0]);
    
  /* Attach the new accelerator group to the window. */
  
  /* Attribute list for gtkglarea widget. Specifies a
     list of Boolean attributes and enum/integer
     attribute/value pairs. The last attribute must be
     GDK_GL_NONE. See glXChooseVisual manpage for further
     explanation.
  */
  int attrlist[] = {
    GDK_GL_RGBA,
    GDK_GL_DOUBLEBUFFER,
    GDK_GL_NONE
  };
  
  /* initialize gtk */
  gtk_init(&argc, &argv);

  
  /* Check if OpenGL (GLX extension) is supported. */
  if (gdk_gl_query() == FALSE) {
    g_print("OpenGL not supported\n");
    return 0;
  }
  
  /* Create new top level window. */
  window = gtk_window_new( GTK_WINDOW_TOPLEVEL);
  gtk_window_set_title(GTK_WINDOW(window), "FooPong");
  
  /* Quit form main if got delete event */
  gtk_signal_connect(GTK_OBJECT(window), "delete_event",
		     GTK_SIGNAL_FUNC(gtk_main_quit), NULL);

  /* You should always delete gtk_gl_area widgets before exit or else
     GLX contexts are left undeleted, this may cause problems (=core dump)
     in some systems.
     Destroy method of objects is not automatically called on exit.
     You need to manually enable this feature. Do gtk_quit_add_destroy()
     for all your top level windows unless you are certain that they get
     destroy signal by other means.
  */
  gtk_quit_add_destroy(1, GTK_OBJECT(window));
  
  vbox = GTK_WIDGET(gtk_vbox_new(FALSE, 0));
  gtk_container_set_border_width(GTK_CONTAINER(vbox), 0);
  
  //logo = gtk_label_new("FooPong");
  /* set up the item_factory to show menu */
  accel_group = gtk_accel_group_new ();
  item_factory = gtk_item_factory_new (GTK_TYPE_MENU_BAR, "<main>",accel_group);
  gtk_item_factory_create_items (item_factory, nmenu_items, menu_items, NULL); 
  gtk_window_add_accel_group (GTK_WINDOW (window), accel_group); 
  //if (menubar)
    /* Finally, return the actual menu bar created by the item factory. */
    menubar = gtk_item_factory_get_widget (item_factory, "<main>");        
  
  /* Create new OpenGL widget. */
  glarea = GTK_WIDGET(gtk_gl_area_new(attrlist));
  
  /* Events for widget must be set before X Window is created */
  gtk_widget_set_events(GTK_WIDGET(glarea),
			GDK_EXPOSURE_MASK|
			GDK_KEY_PRESS_MASK|
			GDK_KEY_RELEASE_MASK);
  /* set default size */
  gtk_gl_area_size(GTK_GL_AREA(glarea), 640,400);

  /* Connect signal handlers */
  /* Redraw image when exposed. */
  gtk_signal_connect(GTK_OBJECT(glarea), "expose_event",
		     GTK_SIGNAL_FUNC(draw), NULL);
  /* When window is resized viewport needs to be resized also. */
  gtk_signal_connect(GTK_OBJECT(glarea), "configure_event",
		     GTK_SIGNAL_FUNC(reshape), NULL);
  /* Do initialization when widget has been realized. */
  gtk_signal_connect(GTK_OBJECT(glarea), "realize",
		     GTK_SIGNAL_FUNC(init), NULL);
  /* Capture keypress events */
  gtk_signal_connect(GTK_OBJECT(glarea), "key_press_event",
		     GTK_SIGNAL_FUNC(key_press_event), NULL);
  gtk_signal_connect(GTK_OBJECT(glarea), "key_release_event",
		     GTK_SIGNAL_FUNC(key_release_event), NULL);
  
  /* construct widget hierarchy  */
  gtk_container_add(GTK_CONTAINER(window),GTK_WIDGET(vbox));
  //gtk_box_pack_start(GTK_BOX(vbox),   logo, FALSE, FALSE, 0);
  gtk_box_pack_start (GTK_BOX (vbox), menubar, FALSE, TRUE, 0); 
  gtk_box_pack_start(GTK_BOX(vbox), glarea,  TRUE,  TRUE, 0);
  
  /* show all widgets */
  gtk_widget_show(GTK_WIDGET(glarea));
  //gtk_widget_show(GTK_WIDGET(logo));
  gtk_widget_show(menubar);
  gtk_widget_show(GTK_WIDGET(vbox));
  gtk_widget_show(window);
  
  /* set focus to glarea widget */
  GTK_WIDGET_SET_FLAGS(glarea, GTK_CAN_FOCUS);
  gtk_widget_grab_focus(GTK_WIDGET(glarea));
  
  /* animating */
  gtk_idle_add((GtkFunction)animate, glarea);
  //gtk_timeout_add(10,(GtkFunction)animate,glarea); 
  game_init();
#ifdef SOUND_LINUX
  init_sound();
#endif
  gtk_main();


  return 0;
}
